@@ -22,7 +22,7 @@ class RootUpdateProgress(UpdateProgress):
         1 << x for x in range(UpdateProgress._num_op_codes, UpdateProgress._num_op_codes + 4)]
     _num_op_codes = UpdateProgress._num_op_codes + 4
 
-    __slots__ = tuple()
+    __slots__ = ()
 
 
 BEGIN = RootUpdateProgress.BEGIN
@@ -38,7 +38,7 @@ class RootModule(Submodule):
     """A (virtual) Root of all submodules in the given repository. It can be used
     to more easily traverse all submodules of the master repository"""
 
-    __slots__ = tuple()
+    __slots__ = ()
 
     k_root_name = '__ROOT__'
 
@@ -265,7 +265,7 @@ class RootModule(Submodule):
                                     # this way, it will be checked out in the next step
                                     # This will change the submodule relative to us, so
                                     # the user will be able to commit the change easily
-                                    log.warn("Current sha %s was not contained in the tracking\
+                                    log.warning("Current sha %s was not contained in the tracking\
              branch at the new remote, setting it the the remote's tracking branch", sm.hexsha)
                                     sm.binsha = rref.commit.binsha
                                 # END reset binsha
