@@ -219,8 +219,8 @@ class SymbolicReference(object):
         else:
             try:
                 invalid_type = self.repo.rev_parse(commit).type != Commit.type
-            except (BadObject, BadName):
-                raise ValueError("Invalid object: %s" % commit)
+            except (BadObject, BadName) as e:
+                raise ValueError("Invalid object: %s" % commit) from e
             # END handle exception
         # END verify type
 
@@ -301,8 +301,8 @@ class SymbolicReference(object):
             try:
                 obj = self.repo.rev_parse(ref + "^{}")    # optionally deref tags
                 write_value = obj.hexsha
-            except (BadObject, BadName):
-                raise ValueError("Could not extract object from %s" % ref)
+            except (BadObject, BadName) as e:
+                raise ValueError("Could not extract object from %s" % ref) from e
             # END end try string
         else:
             raise ValueError("Unrecognized Value: %r" % ref)
@@ -445,12 +445,14 @@ class SymbolicReference(object):
                     made_change = False
                     dropped_last_line = False
                     for line in reader:
+                        line = line.decode(defenc)
+                        _, _, line_ref = line.partition(' ')
+                        line_ref = line_ref.strip()
                         # keep line if it is a comment or if the ref to delete is not
                         # in the line
                         # If we deleted the last line and this one is a tag-reference object,
                         # we drop it as well
-                        line = line.decode(defenc)
-                        if (line.startswith('#') or full_ref_path not in line) and \
+                        if (line.startswith('#') or full_ref_path != line_ref) and \
                                 (not dropped_last_line or dropped_last_line and not line.startswith('^')):
                             new_lines.append(line)
                             dropped_last_line = False
@@ -466,7 +468,7 @@ class SymbolicReference(object):
                     # write-binary is required, otherwise windows will
                     # open the file in text mode and change LF to CRLF !
                     with open(pack_file_path, 'wb') as fd:
-                        fd.writelines(l.encode(defenc) for l in new_lines)
+                        fd.writelines(line.encode(defenc) for line in new_lines)
 
             except (OSError, IOError):
                 pass  # it didn't exist at all
